@@ -5,28 +5,38 @@
 
 #ifdef _WIN32
 #include <windows.h>
+
+#include "specific_os.h"
 #endif
 
 #include "options.h"
-#include "save.h"
 #include "help.h"
+#include "save_image.h"
 
 
 int main(int argc, char *argv[]) {
+    std::vector<std::string> argVector;
+
 #ifdef _WIN32
     SetConsoleOutputCP(CP_UTF8);
     SetConsoleCP(CP_UTF8);
+
+    argVector = SpecificOS::getArgvFromWchar();
 #endif
 
     if (argc == 1) {
-        showHelp("--help");
+        Help::showHelp("--help");
         return 0;
     }
 
-    for (int i = 1; i < argc; ++i) {
+    for (int i = 0; i < argc; ++i) {
         std::string arg = argv[i];
+        argVector.emplace_back(arg);
+    }
+
+    for (const auto& arg : argVector) {
         if (arg == "-h" || arg == "-v" || arg == "--help") {
-            showHelp(argv[i]);
+            Help::showHelp(arg);
             return 0;
         }
     }
@@ -39,7 +49,7 @@ int main(int argc, char *argv[]) {
      * int imageQuality;
     */
 
-    auto optionsResult = getOptions(argc, argv);
+    auto optionsResult = Options::getOptions(argc, argVector);
 
     if (optionsResult.has_value()) {
         auto [
@@ -54,7 +64,7 @@ int main(int argc, char *argv[]) {
             std::filesystem::path pageImagePath = pageImagePaths[i];
             auto [renderingWidthPixels, renderingHeightPixels] = imageSizes[i];
 
-            bool saveResult = savePDFToImage(
+            bool saveResult = SaveImage::savePDFToImage(
                 pdfPath,
                 pageIndexes[i] - 1, pageImagePath,
                 renderingWidthPixels, renderingHeightPixels,
