@@ -5,10 +5,10 @@
 #include <algorithm>
 #include <cmath>
 
-#include "read.h"
+#include "read_pdf.h"
 
 
-std::tuple<bool, std::filesystem::path> getPDFPath(const std::string& str) {
+std::tuple<bool, std::filesystem::path> Options::getPDFPath(const std::string& str) {
     bool isPDF = false;
     std::filesystem::path pdfPath;
     if (std::filesystem::exists(std::filesystem::path(str))) {
@@ -28,7 +28,7 @@ std::tuple<bool, std::filesystem::path> getPDFPath(const std::string& str) {
     return std::make_tuple(isPDF, pdfPath);
 }
 
-std::expected<int, std::string> getDigitsFromString(const std::string& str) {
+std::expected<int, std::string> Options::getDigitsFromString(const std::string& str) {
     std::string digitString = str
     | std::views::filter([](unsigned char c) { return std::isdigit(c); })
     | std::ranges::to<std::string>();
@@ -40,7 +40,11 @@ std::expected<int, std::string> getDigitsFromString(const std::string& str) {
     return std::unexpected("There is no digital.");
 }
 
-std::tuple<int, int> getDpiResolution(const double& pageOriginalWidthPoints, const double& pageOriginalHeightPoints, const int& dpi) {
+std::tuple<int, int> Options::getDpiResolution(
+    const double& pageOriginalWidthPoints,
+    const double& pageOriginalHeightPoints,
+    const int& dpi
+    ) {
     double pageOriginalWidthInches = pageOriginalWidthPoints / 72;
     double pageOriginalHeightInches = pageOriginalHeightPoints / 72;
     int renderingWidthPixels = static_cast<int>(std::round(pageOriginalWidthInches * dpi));
@@ -59,7 +63,7 @@ std::expected<
     >,
     std::string
 >
-getOptions(int argc, char** argv) {
+Options::getOptions(const int& argc, const std::vector<std::string>& argVector) {
     // All available options.
     std::vector<std::string> options = {
         "-o",  // the output folder path of images
@@ -82,34 +86,58 @@ getOptions(int argc, char** argv) {
 
     std::vector<std::string> filtered_options;
 
-    // Distinguish all arguments.
+    /* Distinguish all arguments.
+     * The first element from argv is the program's name, which should be skipped.
+     */
     for (int i = 1; i < argc; ++i) {
-        std::string arg = argv[i];
+        std::string arg = argVector[i];
 
+        /* Recognize the PDF file path. */
         auto recognizePDF = getPDFPath(arg);
 
-        if (arg.size() >= 2 && std::ranges::contains(options, arg.substr(0, 2))) {
+        if (std::get<0>(recognizePDF)) {
+            filtered_options.emplace_back(arg);
+            pdfPath = std::get<1>(recognizePDF);
+        }
+
+        /* Recognize options.
+         * An option with its value can be written like "-d300" or "-d 300".
+         */
+        else if (arg.size() >= 2 && std::ranges::contains(options, arg.substr(0, 2))) {
             filtered_options.emplace_back(arg.substr(0, 2));
 
             if (arg.size() > 2) {
                 filtered_options.emplace_back(arg.substr(2));
             }
-        } else if (!filtered_options.empty() && !std::get<0>(recognizePDF)) {
+        }
+
+        /* Recognize the value of each option. Because of spaces, the value of an option may
+         * be separated to multiple arguments, and here the task is only to combine separate
+         * arguments into one element as the possible value of an option.
+         */
+        else if (!filtered_options.empty()) {
             std::string& lastArg = filtered_options.back();
 
             if (std::ranges::contains(options, lastArg)) {
                 filtered_options.emplace_back(arg);
             } else {
-                if (lastArg[lastArg.size() - 1] == ',') {
-                    filtered_options.back() += arg;
+                /* Page numbers can be written as "1,2,3", "1, 2, 3" or "1 2 3". */
+                if (filtered_options.size() >= 2
+                    && filtered_options[filtered_options.size() - 2] == "-p"
+                    ) {
+                    if (lastArg[lastArg.size() - 1] == ',') {
+                        filtered_options.back() += arg;
+                    } else {
+                        filtered_options.back() += ',';
+                        filtered_options.back() += arg;
+                    }
                 } else {
-                    filtered_options.back() += ',';
+                    /* If the value of an option is written like "1920 x 1080",
+                     * it can be correctly combined as "1920x1080".
+                     */
                     filtered_options.back() += arg;
                 }
             }
-        } else if (std::get<0>(recognizePDF)) {
-            filtered_options.emplace_back(arg);
-            pdfPath = std::get<1>(recognizePDF);
         }
     }
 
@@ -118,7 +146,7 @@ getOptions(int argc, char** argv) {
         return std::unexpected("Please check the path of the PDF file, because there is no PDF file.");
     }
 
-    int pageCount = getPDFPageCount(pdfPath);
+    int pageCount = ReadPDF::getPDFPageCount(pdfPath);
 
     if (pageCount < 1) {
         return std::unexpected("Please check the PDF file, because there is no valid PDF file.");
@@ -298,7 +326,7 @@ getOptions(int argc, char** argv) {
 
     auto [imageExpectedWidthPixels, imageExpectedHeightPixels] = imageSize;
 
-    auto pageOriginalSizes = getPageOriginalSizes(pdfPath, pageIndexes);
+    auto pageOriginalSizes = ReadPDF::getPageOriginalSizes(pdfPath, pageIndexes);
 
     for (int i = 0 ; i < pageIndexes.size(); ++i) {
         int pageIndex = pageIndexes[i];
